==> digikam_7.9.0.orig.tar.xz: digikam-7.9.0/core/dplugins/generic/import/dscanner/dscannerplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : a plugin to acquire images with a digital scanner.
 *
 * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_DSCANNER_PLUGIN_H
#define DIGIKAM_DSCANNER_PLUGIN_H

// Local includes

#include "dplugingeneric.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.generic.DigitalScanner"

namespace KSaneIface
{
    class KSaneWidget;
}

using namespace Digikam;

namespace DigikamGenericDScannerPlugin
{

class DigitalScannerPlugin : public DPluginGeneric
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginGeneric)

public:

    explicit DigitalScannerPlugin(QObject* const parent = nullptr);
    ~DigitalScannerPlugin()              override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;

    void setup(QObject* const)           override;
    void cleanUp()                       override;

private Q_SLOTS:

    void slotDigitalScanner();

private:

    KSaneIface::KSaneWidget* m_saneWidget = nullptr;
};

} // namespace DigikamGenericDScannerPlugin

#endif // DIGIKAM_DSCANNER_PLUGIN_H

==> digikam_8.5.0.orig.tar.xz: digikam-8.5.0/core/dplugins/generic/import/dscanner/dscannerplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : a plugin to acquire images with a digital scanner.
 *
 * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#pragma once

// Local includes

#include "dplugingeneric.h"

// KDE includes

#include <ksanewidget.h>

#define DPLUGIN_IID "org.kde.digikam.plugin.generic.DigitalScanner"

using namespace Digikam;

namespace DigikamGenericDScannerPlugin
{

class DigitalScannerPlugin : public DPluginGeneric
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginGeneric)

public:

    explicit DigitalScannerPlugin(QObject* const parent = nullptr);
    ~DigitalScannerPlugin()              override = default;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;
    QString handbookSection()      const override;
    QString handbookChapter()      const override;

    void setup(QObject* const)           override;
    void cleanUp()                       override;

private Q_SLOTS:

    void slotDigitalScanner();

private:

    KSaneIface::KSaneWidget* m_saneWidget = nullptr;
};

} // namespace DigikamGenericDScannerPlugin
